@@ -1,234 +1,152 @@
+import datetime
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
+from ddd_objects.lib import get_random_string
+from vpc_control_ao.domain.entity import (
+    Condition,
+    CommandResponse,
+    CommandHost,
+    InstanceUserSetting,
+    InstanceInfo
+)
 from .value_obj import (
-    ContainerArgs,
-    ContainerCommand,
+    AccountID,
+    AccountSecret,
+    ServerEndpoint,
+    DatapipePath,
+    DataBucket,
+    AcceessMode,
+    AccessMode,
+    Capacity,
+    ConfigMapType,
+    CreationTime,
+    FSType,
+    Label,
+    NodeAmount,
+    NodeCreationItemID,
+    NodeCreationStatus,
+    NodeLabel,
+    NodeName,
     DNSPolicy,
+    Operator,
+    PersistentVolumeReclaimPolicy,
+    Provisioner,
+    ReadOnly,
+    ReclaimPolicy,
+    ResourceDict,
+    Server,
+    ServiceAccountName,
+    StorageClassName,
+    VolumeBindingMode,
+    ZoneID,
     DockerImageName,
-    EnvVarSourceType,
-    HTTPHeader,
+    NodeType,
+    Base64String,
+    NetworkScheme,
+    SecurityGroupID,
+    ContainerCommand,
+    Number,
+    PayType,
+    Status,
+    InstanceTypeStatusCategory,
+    NodeStatus,
+    Path,
     ImagePullPolicy,
     Integer,
-    JobStatus,
-    LabelDict,
-    LabelSelectorOperator,
-    MatchLabels,
-    NetworkScheme,
-    NodeSelectorDict,
-    PathMode,
-    PayType,
-    PodResourceDict,
-    Protocol,
-    RestartPolicy,
-    Value,
-    Number,
-    BandWidth,
-    DNSType,
-    GPUType,
-    NodeName,
-    Subdomain,
-    VolumeName,
-    VolumeType,
-    ZoneID,
-    Bool,
-    Time,
-    Path,
-    Port,
-    Version,
-    Password,
-    ServiceType,
-    DNSLine,
-    SecurityGroupID,
-    NodeType,
-    KeyType,
-    DomainName,
-    RegionID,
-    RecordID,
-    Price,
-    Token,
-    NodeLabel,
-    Output,
-    Command,
-    Size,
-    InstanceID,
-    Key,
-    Endpoint,
-    Name,
-    InstanceName,
-    Type,
-    InstanceTypeStatus,
-    Hostname,
-    IngressHost,
-    InternetPayType,
+    RestartNumber,
     ImageID,
-    Usage,
-    NodeStatus,
-    Info,
-    Weight,
-    ID,
-    PodStatus,
+    GPUType,
+    Time,
+    InstanceTypeStatus,
+    Key,
+    InstanceID,
+    LabelSelectorOperator,
+    PathMode,
+    ContainerArgs,
+    RestartPolicy,
+    InternetPayType,
+    Bool,
+    PodResourceDict,
+    Size,
+    RegionID,
+    Value,
     InstanceType,
-    DateTime,
-    TimeInterval,
-    InstanceTypeStatusCategory,
-    Data,
+    LabelDict,
+    Info,
+    Protocol,
     IP,
-    Username,
-    Status
+    Name,
+    PodStatus,
+    Token,
+    VolumeName,
+    Version,
+    EnvVarSourceType,
+    JobStatus,
+    BandWidth,
+    ServiceType,
+    Type,
+    DateTime,
+    VolumeType,
+    Hostname,
+    MatchLabels,
+    Port,
+    HTTPHeader,
+    Price,
+    NodeSelectorDict
 )
 
-class Condition(Entity):
-    def __init__(
-        self,
-        min_cpu_num: Number,
-        max_cpu_num: Number,
-        min_memory_size: Size,
-        max_memory_size: Size,
-        min_gpu_num: Optional[Number] = None,
-        max_gpu_num: Optional[Number] = None,
-        min_gpu_memory_size: Optional[Size] = None,
-        max_gpu_memory_size: Optional[Size] = None
-    ):
-        self.min_cpu_num=min_cpu_num
-        self.max_cpu_num=max_cpu_num
-        self.min_memory_size=min_memory_size
-        self.max_memory_size=max_memory_size
-        self.min_gpu_num=min_gpu_num
-        self.max_gpu_num=max_gpu_num
-        self.min_gpu_memory_size=min_gpu_memory_size
-        self.max_gpu_memory_size=max_gpu_memory_size
+# class Condition(Entity):
+#     def __init__(
+#         self,
+#         min_cpu_num: Number,
+#         max_cpu_num: Number,
+#         min_memory_size: Size,
+#         max_memory_size: Size,
+#         min_gpu_num: Optional[Number] = None,
+#         max_gpu_num: Optional[Number] = None,
+#         min_gpu_memory_size: Optional[Size] = None,
+#         max_gpu_memory_size: Optional[Size] = None
+#     ):
+#         self.min_cpu_num=min_cpu_num
+#         self.max_cpu_num=max_cpu_num
+#         self.min_memory_size=min_memory_size
+#         self.max_memory_size=max_memory_size
+#         self.min_gpu_num=min_gpu_num
+#         self.max_gpu_num=max_gpu_num
+#         self.min_gpu_memory_size=min_gpu_memory_size
+#         self.max_gpu_memory_size=max_gpu_memory_size
 
-class InstanceInfo(ExpiredEntity):
-    def __init__(
-        self,
-        id: ID,
-        status: Status,
-        security_group_id: List[SecurityGroupID],
-        instance_type: InstanceType,
-        name: Name,
-        hostname: Hostname,
-        price: Price,
-        image_id: ImageID,
-        region_id: RegionID,
-        zone_id: ZoneID,
-        internet_pay_type: InternetPayType,
-        pay_type: PayType,
-        create_time: DateTime,
-        os_name: Name,
-        public_ip: List[IP],
-        private_ip: IP,
-        bandwidth_in: BandWidth,
-        bandwidth_out: BandWidth,
-        expired_time: DateTime,
-        auto_release_time: DateTime,
-        key_name: Name,
-        _life_time: Number = Number(5)
-    ):
-        self.id=id
-        self.status=status
-        self.security_group_id=security_group_id
-        self.instance_type=instance_type
-        self.name=name
-        self.hostname=hostname
-        self.price=price
-        self.image_id=image_id
-        self.region_id=region_id
-        self.zone_id=zone_id
-        self.internet_pay_type=internet_pay_type
-        self.pay_type=pay_type
-        self.create_time=create_time
-        self.os_name=os_name
-        self.public_ip=public_ip
-        self.private_ip=private_ip
-        self.bandwidth_in=bandwidth_in
-        self.bandwidth_out=bandwidth_out
-        self.expired_time=expired_time
-        self.auto_release_time=auto_release_time
-        self.key_name=key_name
-        self._life_time=_life_time
-        super().__init__(_life_time)
+# class InstanceUserSetting(Entity):
+#     def __init__(
+#         self,
+#         name: Name,
+#         password: Password,
+#         image_id: ImageID,
+#         region_id: RegionID,
+#         exclude_instance_types: List[InstanceType],
+#         user_data: Optional[Data] = None,
+#         internet_pay_type: Type = Type('PayByTraffic'),
+#         amount: InstanceAmount = InstanceAmount(1),
+#         bandwidth_in: BandWidth = BandWidth(200),
+#         bandwidth_out: BandWidth = BandWidth(1),
+#         disk_size: Size = Size(20),
+#         key_name: Name = Name('ansible'),
+#         inner_connection: Bool = Bool(True)
+#     ):
+#         self.name=name
+#         self.password=password
+#         self.image_id=image_id
+#         self.region_id=region_id
+#         self.exclude_instance_types=exclude_instance_types
+#         self.user_data=user_data
+#         self.internet_pay_type=internet_pay_type
+#         self.amount=amount
+#         self.bandwidth_in=bandwidth_in
+#         self.bandwidth_out=bandwidth_out
+#         self.disk_size=disk_size
+#         self.key_name=key_name
+#         self.inner_connection=inner_connection
 
-class InstanceUserSetting(Entity):
-    def __init__(
-        self,
-        name: Name,
-        password: Password,
-        image_id: ImageID,
-        region_id: RegionID,
-        exclude_instance_types: List[InstanceType],
-        user_data: Optional[Data] = None,
-        internet_pay_type: Type = Type('PayByTraffic'),
-        amount: Number = Number(1),
-        bandwidth_in: BandWidth = BandWidth(200),
-        bandwidth_out: BandWidth = BandWidth(1),
-        disk_size: Size = Size(20),
-        key_name: Name = Name('ansible'),
-        inner_connection: Bool = Bool(True)
-    ):
-        self.name=name
-        self.password=password
-        self.image_id=image_id
-        self.region_id=region_id
-        self.exclude_instance_types=exclude_instance_types
-        self.user_data=user_data
-        self.internet_pay_type=internet_pay_type
-        self.amount=amount
-        self.bandwidth_in=bandwidth_in
-        self.bandwidth_out=bandwidth_out
-        self.disk_size=disk_size
-        self.key_name=key_name
-        self.inner_connection=inner_connection
-
-class CommandSetting(Entity):
-    def __init__(
-        self,
-        command: Command = Command('echo 123'),
-        forks: Number = Number(100),
-        timeout: Number = Number(30),
-        password: Password = None,
-        username: Username = Username('root'),
-        port: Port = Port(22),
-        inner_connection: Bool = Bool(True)
-    ):
-        self.command=command
-        self.forks=forks
-        self.timeout=timeout
-        self.password=password
-        self.username=username
-        self.port=port
-        self.inner_connection=inner_connection
-
-class CommandResult(Entity):
-    def __init__(
-        self,
-        output: Output,
-        instance_id: InstanceID,
-        instance_name: InstanceName,
-        ip: IP,
-        succeed: Bool
-    ):
-        self.output=output
-        self.instance_id=instance_id
-        self.instance_name=instance_name
-        self.ip=ip
-        self.succeed=succeed
-
-class OSSOperationInfo(Entity):
-    def __init__(
-        self,
-        name: Name,
-        endpoint: Endpoint,
-        bucket_name: Name,
-        local_path: Path,
-        target_path: Path,
-        with_tar: Bool = Bool(False)
-    ):
-        self.name=name
-        self.endpoint=endpoint
-        self.bucket_name=bucket_name
-        self.local_path=local_path
-        self.target_path=target_path
-        self.with_tar=with_tar
 
 class NodeUserSetting(Entity):
     def __init__(
@@ -243,11 +161,11 @@ class NodeUserSetting(Entity):
         node_type: NodeType = NodeType('worker'),
         postfix: Bool = Bool(True),
         diff_instance_type: Bool = Bool(False),
-        random_password: Bool = Bool(True),
+        random_password: Bool = Bool(False),
         internet_pay_type: Type = Type('PayByTraffic'),
         master_ip: Optional[IP] = None,
         inner_connection: Bool = Bool(True),
-        amount: Number = Number(1)
+        amount: Number = NodeAmount(1)
     ):
         self.name=name
         self.k3s_token=k3s_token
@@ -264,6 +182,32 @@ class NodeUserSetting(Entity):
         self.master_ip=master_ip
         self.inner_connection=inner_connection
         self.amount=amount
+        if amount.get_value() > 1:
+            self.postfix = Bool(True)
+            self.add_postfix()
+            self.name = NodeName(self.name.get_value()+'-')
+        else:
+            self.add_postfix()
+    
+    def add_postfix(self):
+        node_type = self.node_type.get_value()
+        node_name = self.name.get_value()
+        node_type_len = len(node_type.split('-'))
+        node_name_len = len(node_name.split('-'))
+        if self.postfix.get_value() and node_name_len-node_type_len==1:
+            name = f'{self.name.get_value()}-{get_random_string(5).lower()}'
+            self.name = NodeName(name)
+
+class ReleaseNodeInfo(Entity):
+    def __init__(
+        self,
+        node_name: NodeName,
+        region_id: RegionID,
+        instance_id: InstanceID
+    ) -> None:
+        self.node_name = node_name
+        self.region_id = region_id
+        self.instance_id = instance_id
 
 class NodeInfo(ExpiredEntity):
     def __init__(
@@ -283,7 +227,7 @@ class NodeInfo(ExpiredEntity):
         security_group_id: List[SecurityGroupID],
         node_label: NodeLabel,
         cpu_number: Number,
-        memory_size: Size,
+        memory_size: Optional[Size],
         gpu_type: GPUType,
         gpu_number: Number,
         instance_type_status: InstanceTypeStatus,
@@ -296,8 +240,8 @@ class NodeInfo(ExpiredEntity):
         private_ip: IP,
         bandwidth_in: BandWidth,
         bandwidth_out: BandWidth,
-        expired_time: DateTime,
-        auto_release_time: DateTime,
+        node_expired_time: Optional[DateTime],
+        auto_release_time: Optional[DateTime],
         key_name: Name,
         run_time: Optional[Time] = None,
         k3s_version: Optional[Version] = None,
@@ -331,7 +275,7 @@ class NodeInfo(ExpiredEntity):
         self.private_ip=private_ip
         self.bandwidth_in=bandwidth_in
         self.bandwidth_out=bandwidth_out
-        self.expired_time=expired_time
+        self.node_expired_time=node_expired_time
         self.auto_release_time=auto_release_time
         self.key_name=key_name
         self.run_time=run_time
@@ -339,101 +283,100 @@ class NodeInfo(ExpiredEntity):
         self._life_time=_life_time
         super().__init__(_life_time)
 
-class InstanceTypeWithStatus(ExpiredEntity):
+class NodeCreationRequest(Entity):
     def __init__(
         self,
-        region_id: RegionID,
-        zone_id: ZoneID,
-        instance_type_id: InstanceType,
-        cpu_number: Number,
-        memory_size: Size,
-        gpu_type: GPUType,
-        gpu_number: Number,
-        status: InstanceTypeStatus,
-        status_category: InstanceTypeStatusCategory,
-        _life_time: Number = Number(5)
-    ):
-        self.region_id=region_id
-        self.zone_id=zone_id
-        self.instance_type_id=instance_type_id
-        self.cpu_number=cpu_number
-        self.memory_size=memory_size
-        self.gpu_type=gpu_type
-        self.gpu_number=gpu_number
-        self.status=status
-        self.status_category=status_category
-        self._life_time=_life_time
-        super().__init__(_life_time)
+        node_user_setting: NodeUserSetting,
+        condition: Condition
+    ) -> None:
+        self.node_user_setting = node_user_setting
+        self.condition = condition
 
-class InstanceTypeUserSetting(Entity):
+class NodeCreationItem(ExpiredEntity):
     def __init__(
         self,
-        region_id: RegionID,
-        zone_id: ZoneID,
-        instance_type_id: InstanceType
-    ):
-        self.region_id=region_id
-        self.zone_id=zone_id
-        self.instance_type_id=instance_type_id
+        id: NodeCreationItemID,
+        node_creation_request: Optional[NodeCreationRequest],
+        creation_time: CreationTime,
+        status: NodeCreationStatus,
+        details: Optional[List[NodeInfo]] = None,
+        entry_time: Optional[DateTime] = None,
+        exit_time: Optional[DateTime] = None,
+        _life_time: Number = Number(86400)
+    ) -> None:
+        self.id = id
+        self.node_creation_request = node_creation_request
+        self.status = status
+        self.creation_time=creation_time
+        self.details = details
+        self.entry_time = entry_time
+        self.exit_time = exit_time
+        self._life_time = _life_time
+        super().__init__(_life_time=_life_time)
 
-class InstanceUsageInfo(ExpiredEntity):
-    def __init__(
-        self,
-        instance_id: InstanceID,
-        instance_name: InstanceName,
-        cpu_number: Number,
-        cpu_usage: Usage,
-        memory_size: Size,
-        memory_usage: Usage,
-        flow_in: Size,
-        flow_out: Size,
-        disk_size: Size,
-        disk_usage: Usage,
-        io_in: Number,
-        io_out: Number,
-        _life_time: Number = Number(5)
-    ):
-        self.instance_id=instance_id
-        self.instance_name=instance_name
-        self.cpu_number=cpu_number
-        self.cpu_usage=cpu_usage
-        self.memory_size=memory_size
-        self.memory_usage=memory_usage
-        self.flow_in=flow_in
-        self.flow_out=flow_out
-        self.disk_size=disk_size
-        self.disk_usage=disk_usage
-        self.io_in=io_in
-        self.io_out=io_out
-        self._life_time=_life_time
-        super().__init__(_life_time)
+    def is_sending_timeout(self, timeout=30):
+        if self.status.is_sent():
+            diff = datetime.datetime.utcnow()-self.status.changed_time
+            return diff.seconds>timeout
+        return False
 
-class NodeMeta(ExpiredEntity):
-    def __init__(
-        self,
-        name: NodeName,
-        status: NodeStatus,
-        run_time: Time,
-        k3s_version: Version,
-        label: NodeLabel,
-        private_ip: IP,
-        _life_time: Number = Number(5)
-    ):
-        self.name=name
-        self.status=status
-        self.run_time=run_time
-        self.k3s_version=k3s_version
-        self.label=label
-        self.private_ip=private_ip
-        self._life_time=_life_time
-        super().__init__(_life_time)
+
+# class InstanceInfo(ExpiredEntity):
+#     def __init__(
+#         self,
+#         id: ID,
+#         status: Status,
+#         security_group_id: List[SecurityGroupID],
+#         instance_type: InstanceType,
+#         name: Name,
+#         hostname: Hostname,
+#         price: Price,
+#         image_id: ImageID,
+#         region_id: RegionID,
+#         zone_id: ZoneID,
+#         internet_pay_type: InternetPayType,
+#         pay_type: PayType,
+#         create_time: DateTime,
+#         os_name: Name,
+#         public_ip: List[IP],
+#         private_ip: Optional[IP],
+#         bandwidth_in: BandWidth,
+#         bandwidth_out: BandWidth,
+#         instance_expired_time: DateTime,
+#         auto_release_time: DateTime,
+#         key_name: Name,
+#         _life_time: Number = Number(5)
+#     ):
+#         self.id=id
+#         self.status=status
+#         self.security_group_id=security_group_id
+#         self.instance_type=instance_type
+#         self.name=name
+#         self.hostname=hostname
+#         self.price=price
+#         self.image_id=image_id
+#         self.region_id=region_id
+#         self.zone_id=zone_id
+#         self.internet_pay_type=internet_pay_type
+#         self.pay_type=pay_type
+#         self.create_time=create_time
+#         self.os_name=os_name
+#         self.public_ip=public_ip
+#         self.private_ip=private_ip
+#         self.bandwidth_in=bandwidth_in
+#         self.bandwidth_out=bandwidth_out
+#         self.instance_expired_time=instance_expired_time
+#         self.auto_release_time=auto_release_time
+#         self.key_name=key_name
+#         self._life_time=_life_time
+#         super().__init__(_life_time)
 
 class Namespace(ExpiredEntity):
     def __init__(
         self,
         name: Name,
         status: Status,
-        age: TimeInterval,
+        age: DateTime,
         _life_time: Number = Number(5)
     ):
         self.name=name
@@ -446,7 +389,7 @@ class Secret(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        age: TimeInterval,
+        age: DateTime,
         namespace: Name,
         _life_time: Number = Number(5)
     ):
@@ -456,19 +399,18 @@ class Secret(ExpiredEntity):
         self._life_time=_life_time
         super().__init__(_life_time)
 
-class ConfigMap(ExpiredEntity):
+class SecretUserSetting(Entity):
     def __init__(
         self,
         name: Name,
-        age: TimeInterval,
-        namespace: Name,
-        _life_time: Number = Number(5)
+        key: Key,
+        value: Base64String,
+        namespace: Name
     ):
         self.name=name
-        self.age=age
+        self.key=key
+        self.value=value
         self.namespace=namespace
-        self._life_time=_life_time
-        super().__init__(_life_time)
 
 class ConfigMapUserSetting(Entity):
     def __init__(
@@ -476,7 +418,7 @@ class ConfigMapUserSetting(Entity):
         name: Name,
         key: Key,
         value: Value,
-        key_type: KeyType,
+        key_type: ConfigMapType,
         namespace: Name
     ):
         self.name=name
@@ -485,24 +427,25 @@ class ConfigMapUserSetting(Entity):
         self.key_type=key_type
         self.namespace=namespace
 
-class SecretUserSetting(Entity):
+class ConfigMap(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        key: Key,
-        value: Value,
-        namespace: Name
+        age: DateTime,
+        namespace: Name,
+        _life_time: Number = Number(5)
     ):
         self.name=name
-        self.key=key
-        self.value=value
+        self.age=age
         self.namespace=namespace
+        self._life_time=_life_time
+        super().__init__(_life_time)
 
 class Deployment(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        age: TimeInterval,
+        age: DateTime,
         namespace: Name,
         ready_info: Info,
         _life_time: Number = Number(5)
@@ -520,10 +463,10 @@ class Pod(ExpiredEntity):
         name: Name,
         node_name: NodeName,
         pod_status: PodStatus,
-        age: TimeInterval,
+        age: DateTime,
         pod_ip: IP,
         namespace: Name,
-        restarts: Number,
+        restarts: RestartNumber,
         readiness_info: Optional[Info],
         _life_time: Number = Number(5)
     ):
@@ -538,33 +481,36 @@ class Pod(ExpiredEntity):
         self._life_time=_life_time
         super().__init__(_life_time)
 
-class PodOSSOperationInfo(Entity):
+class NodeMeta(Entity):
     def __init__(
         self,
-        name: Name,
-        cluster_name: Name,
-        namespace_name: Name,
-        pod_name: Name,
-        container_name: Name,
-        target_dir: Path,
-        local_path: Path
+        name: NodeName,
+        status: NodeStatus,
+        run_time: Time,
+        k3s_version: Version,
+        private_ip: IP,
+        label: NodeLabel
     ):
         self.name=name
-        self.cluster_name=cluster_name
-        self.namespace_name=namespace_name
-        self.pod_name=pod_name
-        self.container_name=container_name
-        self.target_dir=target_dir
-        self.local_path=local_path
+        self.status=status
+        self.run_time=run_time
+        self.k3s_version=k3s_version
+        self.private_ip=private_ip
+        self.label=label
 
-class ResourceOSSSetting(Entity):
+class PodContainer(ExpiredEntity):
     def __init__(
         self,
-        cluster_name: Name,
-        target_paths: List[Path]
+        pod_name: Name,
+        init_container_info: Info,
+        container_info: Info,
+        _life_time: Number = Number(5)
     ):
-        self.cluster_name=cluster_name
-        self.target_paths=target_paths
+        self.pod_name=pod_name
+        self.init_container_info=init_container_info
+        self.container_info=container_info
+        self._life_time=_life_time
+        super().__init__(_life_time)
 
 class Ingress(ExpiredEntity):
     def __init__(
@@ -585,36 +531,6 @@ class Ingress(ExpiredEntity):
         self.namespace=namespace
         self._life_time=_life_time
         super().__init__(_life_time)
-    @property
-    def hosts(self):
-        return [IngressHost(h) for h in self.host_info.get_value().split(',')]
-    
-    @property
-    def addresses(self):
-        return [Value(a) for a in self.address_info.get_value().split(',')]
-
-class DNSRecord(Entity):
-    def __init__(
-        self,
-        domain_name: DomainName,
-        subdomain: Subdomain,
-        value: Value,
-        id: Optional[RecordID] = None,
-        weight: Optional[Weight] = None,
-        dns_type: DNSType = DNSType('A'),
-        ttl: Number = Number(600),
-        priority: Optional[Number] = None,
-        line: Optional[DNSLine] = None
-    ):
-        self.domain_name=domain_name
-        self.subdomain=subdomain
-        self.value=value
-        self.id=id
-        self.weight=weight
-        self.dns_type=dns_type
-        self.ttl=ttl
-        self.priority=priority
-        self.line=line
 
 class Service(ExpiredEntity):
     def __init__(
@@ -636,20 +552,6 @@ class Service(ExpiredEntity):
         self._life_time=_life_time
         super().__init__(_life_time)
 
-class PodContainer(ExpiredEntity):
-    def __init__(
-        self,
-        pod_name: Name,
-        init_container_info: Info,
-        container_info: Info,
-        _life_time: Number = Number(5)
-    ):
-        self.pod_name=pod_name
-        self.init_container_info=init_container_info
-        self.container_info=container_info
-        self._life_time=_life_time
-        super().__init__(_life_time)
-
 class KeyToPath(Entity):
     def __init__(
         self,
@@ -661,17 +563,6 @@ class KeyToPath(Entity):
         self.path=path
         self.mode=mode
 
-# class PodSecurityContext(Entity):
-#     def __init__(
-#         self,
-#         run_as_user: Optional[Number] = None,
-#         run_as_group: Optional[Number] = None,
-#         run_as_non_root: Optional[Bool] = None
-#     ):
-#         self.run_as_user=run_as_user
-#         self.run_as_group=run_as_group
-#         self.run_as_non_root=run_as_non_root
-
 class EnvVarSource(Entity):
     def __init__(
         self,
@@ -711,18 +602,29 @@ class VolumeSource(Entity):
         self.default_mode=default_mode
         self.items = items
 
+class PersistentVolumeClaimVolumeSource(Entity):
+    def __init__(
+        self,
+        claim_name: Name,
+        read_only: Optional[ReadOnly] = None
+    ) -> None:
+        self.claim_name = claim_name
+        self.read_only = read_only
+
 class VolumeSetting(Entity):
     def __init__(
         self,
         volume_name: VolumeName,
         empty_dir: Optional[Bool] = None,
         config_map: Optional[VolumeSource] = None,
-        secret: Optional[VolumeSource] = None
+        secret: Optional[VolumeSource] = None,
+        persistent_volume_claim: Optional[PersistentVolumeClaimVolumeSource] = None
     ):
         self.volume_name=volume_name
         self.empty_dir=empty_dir
         self.config_map=config_map
         self.secret=secret
+        self.persistent_volume_claim = persistent_volume_claim
 
 class VolumeMount(Entity):
     def __init__(
@@ -844,18 +746,18 @@ class ContainerSetting(Entity):
         self,
         container_name: Name,
         container_image: DockerImageName,
-        env_vars: Optional[List[EnvVar]]=None,
-        command: Optional[ContainerCommand]=None,
-        args: Optional[ContainerArgs]=None,
-        image_pull_policy: Optional[ImagePullPolicy]=ImagePullPolicy('Always'),
-        working_dir: Optional[Path]=None,
-        volume_mount: Optional[List[VolumeMount]]=None,
-        security_context: Optional[SecurityContext]=None,
-        limits: Optional[PodResourceDict]=None,
-        requests: Optional[PodResourceDict]=None,
-        readiness_probe: Optional[Probe]=None,
-        liveness_probe: Optional[Probe]=None,
-        ports: Optional[List[ContainerPort]]=None
+        env_vars: Optional[List[EnvVar]],
+        command: Optional[ContainerCommand],
+        args: Optional[ContainerArgs],
+        image_pull_policy: Optional[ImagePullPolicy],
+        working_dir: Optional[Path],
+        volume_mount: Optional[List[VolumeMount]],
+        security_context: Optional[SecurityContext],
+        limits: Optional[PodResourceDict],
+        requests: Optional[PodResourceDict],
+        readiness_probe: Optional[Probe],
+        liveness_probe: Optional[Probe],
+        ports: Optional[List[ContainerPort]]
     ):
         self.container_name = container_name
         self.container_image = container_image
@@ -879,7 +781,7 @@ class JobSetting(Entity):
         namespace_name: Name,
         labels: LabelDict,
         containers: List[ContainerSetting],
-        init_containers: Optional[List[ContainerSetting]]=None,
+        init_containers: Optional[List[ContainerSetting]],
         parallelism: Number = Number(1),
         ttl_seconds_after_finished: Number = Number(600),
         restart_policy: RestartPolicy = RestartPolicy('Never'),
@@ -888,7 +790,8 @@ class JobSetting(Entity):
         node_selector: Optional[NodeSelectorDict] = None,
         volumes: Optional[List[VolumeSetting]] = None,
         selector: Optional[LabelSelector] = None,
-        dns_policy: Optional[DNSPolicy] = None
+        dns_policy: Optional[DNSPolicy] = None,
+        service_account_name: Optional[ServiceAccountName] = None
     ):
         self.job_name = job_name
         self.namespace_name = namespace_name
@@ -897,13 +800,17 @@ class JobSetting(Entity):
         self.init_containers = init_containers
         self.parallelism = parallelism
         self.ttl_seconds_after_finished = ttl_seconds_after_finished
-        self.restart_policy = restart_policy
+        if restart_policy is None:
+            self.restart_policy = RestartPolicy('Never')
+        else:
+            self.restart_policy = restart_policy
         self.backoff_limit = backoff_limit
         self.node_name = node_name
         self.node_selector = node_selector
         self.volumes = volumes
         self.selector = selector
         self.dns_policy = dns_policy
+        self.service_account_name = service_account_name
 
 class Job(ExpiredEntity):
     def __init__(
@@ -936,3 +843,136 @@ class PodLogSetting(Entity):
         self.container_name=container_name
         self.tail_lines=tail_lines
 
+class StorageClass(Entity):
+    def __init__(
+        self,
+        name: Name,
+        provisioner: Provisioner,
+        reclaim_policy: ReclaimPolicy,
+        volume_binding_mode: VolumeBindingMode,
+        namespace_name: Name
+    ):
+        self.name=name
+        self.provisioner=provisioner
+        self.reclaim_policy=reclaim_policy
+        self.volume_binding_mode=volume_binding_mode
+        self.namespace_name=namespace_name
+
+class NFSVolumeSource(Entity):
+    def __init__(
+        self,
+        path: Path,
+        server: Server,
+        read_only: Optional[ReadOnly] = None
+    ):
+        self.path=path
+        self.server=server
+        self.read_only=read_only
+
+class LocalVolumeSource(Entity):
+    def __init__(
+        self,
+        path: Path,
+        fs_type: Optional[FSType] = None
+    ):
+        self.path=path
+        self.fs_type=fs_type
+
+class NodeSelectorRequirement(Entity):
+    def __init__(
+        self,
+        key: Key,
+        operator: Operator,
+        values: List[Value]
+    ):
+        self.key=key
+        self.operator=operator
+        self.values=values
+
+class NodeAffinity(Entity):
+    def __init__(
+        self,
+        match_expressions: Optional[List[NodeSelectorRequirement]] = None,
+        match_fields: Optional[List[NodeSelectorRequirement]] = None
+    ):
+        self.match_expressions=match_expressions
+        self.match_fields=match_fields
+
+class PersistentVolume(Entity):
+    def __init__(
+        self,
+        name: Name,
+        namespace: Name,
+        persistent_volume_claim_name: Optional[Name] = None,
+        storage_class_name: Optional[StorageClassName] = None,
+        capacity: Optional[Capacity] = None,
+        access_modes: Optional[List[AccessMode]] = None,
+        persistent_volume_reclaim_policy: Optional[PersistentVolumeReclaimPolicy] = None,
+        nfs: Optional[NFSVolumeSource] = None,
+        local: Optional[LocalVolumeSource] = None,
+        node_affinity: Optional[List[NodeAffinity]] = None
+    ):
+        self.name=name
+        self.namespace=namespace
+        self.persistent_volume_claim_name = persistent_volume_claim_name
+        self.storage_class_name=storage_class_name
+        self.capacity=capacity
+        self.access_modes=access_modes
+        self.persistent_volume_reclaim_policy=persistent_volume_reclaim_policy
+        self.nfs=nfs
+        self.local=local
+        self.node_affinity=node_affinity
+
+class PersistentVolumeClaim(Entity):
+    def __init__(
+        self,
+        name: Name,
+        namespace: Namespace,
+        labels: Optional[Label] = None,
+        access_modes: Optional[List[AcceessMode]] = None,
+        storage_class_name: Optional[StorageClassName] = None,
+        limits: Optional[ResourceDict] = None,
+        requests: Optional[ResourceDict] = None
+    ):
+        self.name=name
+        self.namespace=namespace
+        self.labels=labels
+        self.access_modes=access_modes
+        self.storage_class_name=storage_class_name
+        self.limits=limits
+        self.requests=requests
+
+class DatapipeServerInfo(Entity):
+    def __init__(
+        self,
+        id: AccountID,
+        secret: AccountSecret,
+        endpoint: ServerEndpoint,
+        
+    ) -> None:
+        self.id = id
+        self.secret = secret
+        self.endpoint = endpoint
+        
+
+class DatapipeHost(CommandHost):
+    pass
+
+class DatapipeDataInfo(Entity):
+    def __init__(
+        self,
+        bucket: DataBucket,
+        remote_path: DatapipePath,
+        local_path: DatapipePath,
+        timeout: Number
+    ) -> None:
+        self.bucket = bucket
+        self.remote_path = remote_path
+        self.local_path = local_path
+        self.timeout = timeout
+    
+    def __str__(self) -> str:
+        return self.__dict__
+
+class DatapipeResponse(CommandResponse):
+    pass
\ No newline at end of file
