@@ -1,22 +1,31 @@
-import os, base64
-from ddd_objects.domain.value_obj import ExpiredValueObject
-from ddd_objects.domain.exception import ParameterError, FormatError
+import sys, base64, os, datetime
+from dateutil import parser
+from ddd_objects.domain.value_obj import ExpiredValueObject, ValueObject
+from ddd_objects.domain.exception import FormatError, ValueError, ParameterError
+python_version_minor = sys.version_info.minor
 
 class Number(ExpiredValueObject):
     def __init__(self, value):
-        try:
-            value = float(value)
-        except:
-            raise FormatError(f'The given value ({value}) is not a Number')
         super().__init__(value, None)
 
-class Integer(ExpiredValueObject):
+class InstanceAmount(Number):
     def __init__(self, value):
-        try:
-            value = int(value)
-        except:
-            raise FormatError(f'The given value ({value}) is not a Number')
-        super().__init__(value, None)
+        if not isinstance(value, int) or value<1:
+            raise ValueError('Value for InstanceAmount is invalid.')
+        super().__init__(value)
+
+class NodeAmount(Number):
+    def __init__(self, value):
+        if not isinstance(value, int) or value<1:
+            raise ValueError('Value for NodeAmount is invalid.')
+        super().__init__(value)
+
+class RestartNumber(Number):
+    def __init__(self, value):
+        if isinstance(value, str):
+            parts = value.split(' ')
+            value = parts[0]
+        super().__init__(value)
 
 class Size(ExpiredValueObject):
     def __init__(self, value):
@@ -30,23 +39,6 @@ class Status(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
-class IngressHost(ExpiredValueObject):
-    def __init__(self, value):
-        self.parts = value.split('.')
-        if len(self.parts)>3 or len(self.parts)==1:
-            raise ParameterError('Invaild value')
-        super().__init__(value, None)
-    def get_domain_name(self):
-        if len(self.parts)==2:
-            return DomainName(self.value)
-        elif len(self.parts)==3:
-            return DomainName('.'.join(self.parts[-2:]))
-    def get_subdomain(self):
-        if len(self.parts)==2:
-            return Subdomain('@')
-        elif len(self.parts)==3:
-            return Subdomain(self.parts[0])
-
 class SecurityGroupID(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
@@ -55,6 +47,21 @@ class InstanceType(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
+class Name(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+    def match(self, s):
+        return self.value==s
+    def add(self, s):
+        self.value += s
+        return self
+    def startswith(self, s):
+        return self.value.startswith(s)
+
+class ServiceAccountName(Name):
+    def __init__(self, value):
+        super().__init__(value)
+
 class Hostname(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
@@ -82,10 +89,16 @@ class InternetPayType(ExpiredValueObject):
 class PayType(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
-
-class DateTime(ExpiredValueObject):
+    
+class ConfigMapType(ValueObject):
     def __init__(self, value):
-        super().__init__(value, None)
+        if value not in ['property', 'file']:
+            raise ParameterError('Invaid parameter for ConfigMapType')
+        self.value = value
+    def is_property(self):
+        return self.value=='property'
+    def is_file(self):
+        return self.value=='file'
 
 class IP(ExpiredValueObject):
     def __init__(self, value):
@@ -95,17 +108,37 @@ class BandWidth(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
+class DateTime(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
 class Password(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
+class YamlString(ValueObject):
+    def __init__(self, value):
+        if isinstance(value, int) or isinstance(value, float) \
+            or (isinstance(value, str) and value.isdigit()):
+            value = f'"{value}"'
+        elif not isinstance(value, str):
+            raise ValueError(f'Type {type(value)} is not supported')
+        super().__init__(value)
+
+class Base64String(ExpiredValueObject):
+    def __init__(self, value):
+        value = str(base64.b64encode(value.encode('utf-8')),"utf-8")
+        super().__init__(value, None)
+
 class Data(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
-class Bool(ExpiredValueObject):
+class Type(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
+    def match(self, value):
+        return value==self.value
 
 class Command(ExpiredValueObject):
     def __init__(self, value):
@@ -119,6 +152,10 @@ class Port(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
+class Bool(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
 class Output(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
@@ -135,57 +172,6 @@ class Endpoint(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
-class Token(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class NodeLabel(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Usage(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class GPUType(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class InstanceTypeStatus(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-    def is_available(self):
-        return self.value=='Available'
-class InstanceTypeStatusCategory(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-    def is_with_stock(self):
-        return self.value=='WithStock'
-class Time(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Version(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Name(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-    def match(self, value):
-        return self.value==value
-    def add(self, s):
-        self.value += s
-        return self
-
-class ServiceAccountName(Name):
-    def __init__(self, value):
-        super().__init__(value)
-
-class Type(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
 class Path(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
@@ -197,6 +183,8 @@ class NodeType(Type):
         super().__init__(value)
     def is_master(self):
         return self.value=='master'
+    def match(self, value):
+        return self.value==value
 
 class NodeName(Name):
     def __init__(self, value):
@@ -210,7 +198,11 @@ class NodeName(Name):
         master_name = self.value.split('-')[0]+'-master'
         return Name(master_name)
     def get_node_type(self):
-        parts = self.value.split('-')[1:-1]
+        parts = self.value.split('-')
+        if parts[-1].isdigit():
+            parts = parts[1:-2]
+        else:
+            parts = parts[1:-1]
         return NodeType('-'.join(parts))
     def get_type_group_name(self):
         parts = self.value.split('-')[:-1]
@@ -230,65 +222,11 @@ class NodeStatus(ExpiredValueObject):
     def is_schedulable(self):
         return 'SchedulingDisabled' not in self.value
 
-class YamlString(ExpiredValueObject):
-    def __init__(self, value):
-        if isinstance(value, int) or isinstance(value, float) \
-            or (isinstance(value, str) and value.isdigit()):
-            value = f'"{value}"'
-        elif not isinstance(value, str):
-            raise ValueError(f'Type {type(value)} is not supported')
-        super().__init__(value)
-
-class Base64String(ExpiredValueObject):
-    def __init__(self, value):
-        value = str(base64.b64encode(value.encode('utf-8')),"utf-8")
-        super().__init__(value, None)
-
-class TimeInterval(ExpiredValueObject):
+class Token(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
-class Key(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Value(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class KeyType(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Info(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class DomainName(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Subdomain(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class RecordID(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class Weight(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class DNSType(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class DNSLine(ExpiredValueObject):
-    def __init__(self, value):
-        super().__init__(value, None)
-
-class ServiceType(ExpiredValueObject):
+class InstanceStatus(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
@@ -296,11 +234,63 @@ class Time(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
 
+class Version(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Key(ValueObject):
+    pass
+
+class Value(ValueObject):
+    pass
+
+class GPUType(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class InstanceStatusCategory(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class InstanceTypeStatus(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class InstanceTypeStatusCategory(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class NodeLabel(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class InstanceIf(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Usage(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Info(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class TimeInterval(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Label(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class ServiceType(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
 class PodStatus(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
-    def is_running(self):
-        return 'Running' in self.value
 
 class DockerImageName(ExpiredValueObject):
     def __init__(self, value):
@@ -380,4 +370,137 @@ class LabelSelectorOperator(ExpiredValueObject):
 
 class JobStatus(ExpiredValueObject):
     def __init__(self, value):
-        super().__init__(value, None)
\ No newline at end of file
+        super().__init__(value, None)
+
+class Integer(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Provisioner(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class ReclaimPolicy(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class VolumeBindingMode(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Server(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class ReadOnly(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class FSType(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Operator(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class StorageClassName(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class Capacity(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class AccessMode(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class PersistentVolumeReclaimPolicy(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class AcceessMode(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class ResourceDict(ExpiredValueObject):
+    def __init__(self, value):
+        super().__init__(value, None)
+
+class NodeCreationItemID(ID):
+    pass
+
+class CreationTime(ValueObject):
+    def __init__(self, value=None):
+        if value is None:
+            value = datetime.datetime.utcnow()
+        elif isinstance(value, str):
+            value = parser.parse(value)
+        else:
+            print(value, type(value))
+        super().__init__(value)
+    def __str__(self) -> str:
+        return self.value.replace(microsecond=0).isoformat()
+
+class NodeCreationStatus(ValueObject):
+    def __init__(self, value=None) -> None:
+        value = value or 'Pending'
+        self.value = value
+        self._set_changed_time()
+
+    def _set_changed_time(self):
+        self.changed_time = datetime.datetime.utcnow()
+
+    def set_sent(self):
+        self.value = 'Sent'
+        self._set_changed_time()
+
+    def set_created(self):
+        self.value = 'Created'
+        self._set_changed_time()
+
+    def set_deleted(self):
+        self.value = 'Deleted'
+        self._set_changed_time()
+
+    def set_succeed(self):
+        self.value = 'Succeed'
+        self._set_changed_time()
+
+    def set_failed(self):
+        self.value = 'Failed'
+        self._set_changed_time()
+
+    def is_sent(self):
+        return self.value=='Sent'
+
+    def is_created(self):
+        return self.value=='Created'
+
+    def is_pending(self):
+        return self.value=='Pending'
+
+    def is_deleted(self):
+        return self.value=='Deleted'
+
+class AccountID(ValueObject):
+    pass
+
+class AccountSecret(ValueObject):
+    pass
+
+class ServerEndpoint(ValueObject):
+    pass
+
+class DataBucket(ValueObject):
+    pass
+
+class DatapipePath(ValueObject):
+    pass
+
+class DatapipeRequestID(ValueObject):
+    pass
+
+class Text(ValueObject):
+    pass
\ No newline at end of file
