@@ -23,8 +23,6 @@ from .do import (
     PodContainerDO,
     PodDO,
     PodLogSettingDO,
-    PodOSSOperationInfoDO,
-    ResourceOSSSettingDO,
     SecretDO,
     SecretUserSettingDO,
     ServiceDO,
@@ -46,7 +44,6 @@ class K3SController:
                 error_traceback = info['detail']['error_traceback']
             raise error_factory.make(return_code)(error_traceback)
 
-    @exception_class_dec(max_try=1)
     def check_connection(self, timeout=3):
         response=requests.get(f'{self.url}', headers=self.header, timeout=timeout)
         info = json.loads(response.text)
@@ -56,7 +53,6 @@ class K3SController:
         else:
             return False
 
-    @exception_class_dec(max_try=1)
     def create_node(self, condition: ConditionDO, node_user_setting: NodeUserSettingDO, timeout=1200):
         data = {
             "condition": condition.dict(),
@@ -66,12 +62,8 @@ class K3SController:
         response=requests.post(f'{self.url}/node', headers=self.header, data=data, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [NodeInfoDO(**info) for info in infos]
+        return [NodeInfoDO(**info) for info in infos]
 
-    @exception_class_dec(max_try=1)
     def delete_nodes(self, node_infos: List[ReleaseNodeInfoDO], timeout=60):
         data = [info.dict() for info in node_infos]
         data = json.dumps(data)
@@ -80,7 +72,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def cordon(self, node_name:str, timeout=3):
         response = requests.get(f'{self.url}/node/cordon/node_name/{node_name}', 
             headers=self.header, timeout=timeout)
@@ -88,7 +79,6 @@ class K3SController:
         self._check_error(response.status_code, succeed)
         return succeed
 
-    @exception_class_dec(max_try=1)
     def get_nodes_by_name(self, node_name:str, timeout=10):
         response=requests.get(f'{self.url}/nodes/node_name/{node_name}', 
             headers=self.header, timeout=timeout)
@@ -96,7 +86,6 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeInfoDO(**info) for info in infos]
 
-    @exception_class_dec(max_try=1)
     def get_node_metas(self,  timeout=7):
         response=requests.get(f'{self.url}/node_metas', 
             headers=self.header, timeout=timeout)
@@ -104,7 +93,6 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeMetaDO(**meta) for meta in infos]
 
-    @exception_class_dec(max_try=1)
     def add_node_label(self, node_name: str, key: str, value: str, timeout=3):
         response=requests.post(f'{self.url}/label/node_name/{node_name}/key/{key}/value/{value}', 
             headers=self.header, timeout=timeout)
@@ -112,18 +100,13 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return infos
 
-    @exception_class_dec(max_try=1)
     def get_namespaces(self,  timeout=10):
         response=requests.get(f'{self.url}/namespaces', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [NamespaceDO(**namespace) for namespace in infos]
+        return [NamespaceDO(**namespace) for namespace in infos]
 
-    @exception_class_dec(max_try=1)
     def create_namespace(self,  namespace_name: str, timeout=10):
         response=requests.post(
             f'{self.url}/namespace/namespace_name/{namespace_name}', 
@@ -132,13 +115,12 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def create_secrets(
         self, 
         secret_user_settings: List[SecretUserSettingDO],
         timeout=300
     ):
-        data = [setting.to_json() for setting in secret_user_settings]
+        data = [setting.dict() for setting in secret_user_settings]
         data = json.dumps(data)
         response=requests.post(
             f'{self.url}/secrets', 
@@ -147,19 +129,14 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def get_secrets(self, namespace_name: str, timeout=10):
         response=requests.get(
             f'{self.url}/secrets/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [SecretDO(**s) for s in infos]
+        return [SecretDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def create_config_maps(
         self, 
         config_map_user_settings: List[ConfigMapUserSettingDO],
@@ -174,55 +151,38 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def get_config_maps(self, namespace_name:str, timeout=10):
         response=requests.get(
             f'{self.url}/config_maps/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [ConfigMapDO(**s) for s in infos]
+        return [ConfigMapDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def get_deployments(self, namespace_name:str, timeout=10):
         response=requests.get(
             f'{self.url}/deployments/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [DeploymentDO(**s) for s in infos]
+        return [DeploymentDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def get_ingresses(self, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/ingresses/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [IngressDO(**s) for s in infos]
+        return [IngressDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def get_pods(self, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/pods/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [PodDO(**s) for s in infos]
+        return [PodDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def delete_pod(self, namespace_name:str, pod_name:str, timeout=5):
         response=requests.delete(
             f'{self.url}/pod/namespace_name/{namespace_name}/pod_name/{pod_name}', 
@@ -231,53 +191,30 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
-    def upload_to_oss_from_pod(self, pod_oss_operation_info: PodOSSOperationInfoDO, timeout=1200):
-        data = json.dumps(pod_oss_operation_info.to_json())
-        response=requests.post(
-            f'{self.url}/oss/pod', 
-            headers=self.header, data=data, timeout=timeout)
-        info = json.loads(response.text)
-        self._check_error(response.status_code, info)
-        return info
-
-    @exception_class_dec(max_try=1)
     def get_services(self, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/services/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [ServiceDO(**s) for s in infos]
+        return [ServiceDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def get_pod_containers(self, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/pod_containers/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [PodContainerDO(**s) for s in infos]
+        return [PodContainerDO(**s) for s in infos]
 
-    @exception_class_dec(max_try=1)
     def get_jobs(self, namespace_name:str, timeout=10):
         response=requests.get(
             f'{self.url}/jobs/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        if infos is None:
-            return None
-        else:
-            return [JobDO(**s) for s in infos]
+        return [JobDO(**s) for s in infos]
         
-    @exception_class_dec(max_try=1)
     def create_job(self, job_setting:JobSettingDO, timeout=10):
         data = json.dumps(job_setting.dict())
         response=requests.post(
@@ -285,12 +222,8 @@ class K3SController:
             headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
-        if info is None:
-            return None
-        else:
-            return JobDO(**info)
+        return JobDO(**info)
     
-    @exception_class_dec(max_try=1)
     def get_pod_log(
         self, 
         pod_log_setting: PodLogSettingDO,
@@ -304,7 +237,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def delete_job(
         self,
         namespace_name:str,
@@ -318,7 +250,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def create_storage_class(
         self,
         storage_class: StorageClassDO,
@@ -333,7 +264,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def delete_storage_class(
         self,
         storage_class_name: str,
@@ -347,7 +277,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def create_persistent_volume(
         self,
         persistent_volume: PersistentVolumeDO,
@@ -362,7 +291,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def delete_persistent_volume(
         self,
         persistent_volume_name: str,
@@ -376,7 +304,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def create_persistent_volume_claim(
         self,
         persistent_volume_claim: PersistentVolumeClaimDO,
@@ -391,7 +318,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec(max_try=1)
     def delete_persistent_volume_claim(
         self,
         namespace_name: str,
@@ -406,7 +332,6 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
     def send_node_creation_request(self, request: NodeCreationRequestDO, timeout=3):
         data = json.dumps(request.dict())
         response=requests.post(f'{self.url}/node/request', 
@@ -418,19 +343,13 @@ class K3SController:
         else:
             return id
 
-    @exception_class_dec()
     def find_node_creation_item(self, id: str, timeout=3):
         response=requests.get(f'{self.url}/node/item/id/{id}', 
             headers=self.header, timeout=timeout)
         item = json.loads(response.text)
         self._check_error(response.status_code, item)
-        if item is None:
-            return None
-        else:
-            print(item)
-            return NodeCreationItemDO(**item)
+        return NodeCreationItemDO(**item)
 
-    @exception_class_dec()
     def find_unprocessed_node_creation_item(self, timeout=3):
         response=requests.get(f'{self.url}/node/item/unprocessed', 
             headers=self.header, timeout=timeout)
@@ -441,7 +360,6 @@ class K3SController:
         else:
             return NodeCreationItemDO(**item)
 
-    @exception_class_dec()
     def update_node_creation_item(self, item:NodeCreationItemDO, timeout=10):
         data = json.dumps(item.dict())
         response=requests.put(f'{self.url}/node/item', 
@@ -450,7 +368,6 @@ class K3SController:
         self._check_error(response.status_code, succeed)
         return succeed
 
-    @exception_class_dec()
     def clear_node_creation_item(self, timeout=3):
         response=requests.get(f'{self.url}/node/item/clear', 
             headers=self.header, timeout=timeout)
@@ -458,7 +375,6 @@ class K3SController:
         self._check_error(response.status_code, n)
         return n
 
-    @exception_class_dec()
     def delete_node_creation_item(self, item_id:str, timeout=3):
         response=requests.delete(f'{self.url}/node/item/id/{item_id}', 
             headers=self.header, timeout=timeout)
@@ -466,7 +382,6 @@ class K3SController:
         self._check_error(response.status_code, succeed)
         return succeed
 
-    @exception_class_dec()
     def delete_namespace(self, namespace_name:str, timeout=10):
         response=requests.delete(f'{self.url}/namespace/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
