@@ -1,18 +1,20 @@
 import datetime
-from dataclasses import dataclass
-from typing import Dict, List, Optional, Union
-from ddd_objects.infrastructure.do import BaseDO
+from typing import List, Optional, Union, Dict
 from pydantic import BaseModel
-
-class ConditionDO(BaseModel):
-    min_cpu_num: int
-    max_cpu_num: int
-    min_memory_size: int
-    max_memory_size: int
-    min_gpu_num: Optional[int]=None
-    max_gpu_num: Optional[int]=None
-    min_gpu_memory_size: Optional[int]=None
-    max_gpu_memory_size: Optional[int]=None
+from vpc_control_ao.infrastructure.do import (
+    InstanceCreationRequestDO,
+    InstanceCreationItemDO,
+    CommandItemDO,
+    CommandContextDO,
+    CommandSettingDetailDO,
+    CommandHostDO,
+    CommandRequestDO,
+    CommandResponseDO,
+    ConditionDO,
+    InstanceInfoDO,
+    InstanceUserSettingDO,
+    ReleaseInstanceInfoDO,
+)
 
 class NodeUserSettingDO(BaseModel):
     name: str
@@ -32,6 +34,11 @@ class NodeUserSettingDO(BaseModel):
     amount: int=1
 
 
+class NodeCreationRequestDO(BaseModel):
+    condition: ConditionDO
+    node_user_setting: NodeUserSettingDO
+
+
 class NodeInfoDO(BaseModel):
     node_name: str
     node_type: str
@@ -47,12 +54,12 @@ class NodeInfoDO(BaseModel):
     pay_type: str
     security_group_id: List[str]
     node_label: Union[str, Dict]
-    cpu_number: Optional[int]
-    memory_size: Optional[float]
-    gpu_type: Optional[str]
-    gpu_number: Optional[int]
-    instance_type_status: Optional[str]
-    instance_type_status_category: Optional[str]
+    cpu_number: Optional[int]=None
+    memory_size: Optional[float]=None
+    gpu_type: Optional[str]=None
+    gpu_number: Optional[int]=None
+    instance_type_status: Optional[str]=None
+    instance_type_status_category: Optional[str]=None
     instance_name: str
     instance_status: str
     instance_create_time: str
@@ -61,16 +68,13 @@ class NodeInfoDO(BaseModel):
     private_ip: str
     bandwidth_in: int
     bandwidth_out: int
-    node_expired_time: Optional[str]
-    auto_release_time: Optional[str]
-    key_name: str
-    run_time: Optional[Union[int, datetime.timedelta]]=None
+    node_expired_time: Optional[str]=None
+    auto_release_time: Optional[str]=None
+    key_name: Optional[str]=None
+    run_time: Optional[Union[str, datetime.timedelta]]=None
     k3s_version: Optional[str]=None
     _life_time: int=5
 
-class NodeCreationRequestDO(BaseModel):
-    condition: ConditionDO
-    node_user_setting: NodeUserSettingDO
 
 class NodeCreationItemDO(BaseModel):
     id: str
@@ -82,228 +86,129 @@ class NodeCreationItemDO(BaseModel):
     exit_time: Optional[str]=None
     _life_time: int=86400
 
-@dataclass
-class CommandResultDO(BaseDO):
-    output: str
-    instance_id: str
-    instance_name: str
-    ip: str
-    succeed: bool
 
-@dataclass
-class NamespaceDO(BaseDO):
+
+class NamespaceDO(BaseModel):
     name: str
     status: str
-    age: str
+    age: Union[str, datetime.timedelta]
     _life_time: int=5
 
-@dataclass
-class SecretDO(BaseDO):
+
+class SecretDO(BaseModel):
     name: str
-    age: str
+    age: Union[str, datetime.timedelta]
     namespace: str
     _life_time: int=5
 
-@dataclass
-class SecretUserSettingDO(BaseDO):
+
+class SecretUserSettingDO(BaseModel):
     name: str
     key: str
     value: str
     namespace: str
 
-@dataclass
-class ConfigMapDO(BaseDO):
+
+class ConfigMapDO(BaseModel):
     name: str
-    age: str
+    age: Union[str, datetime.timedelta]
     namespace: str
     _life_time: int=5
 
-@dataclass
-class ConfigMapUserSettingDO(BaseDO):
+
+class ConfigMapUserSettingDO(BaseModel):
     name: str
     key: str
     value: str
+    key_type: str
     namespace: str
-    key_type: str = 'property'
 
-@dataclass
-class ResourceOSSSettingDO(BaseDO):
-    cluster_name: str
-    target_paths: List[str]
 
-@dataclass
-class DeploymentDO(BaseDO):
+class DeploymentDO(BaseModel):
     name: str
-    age: str
+    age: Union[str, datetime.timedelta]
     namespace: str
     ready_info: str
     _life_time: int=5
 
-@dataclass
-class PodDO(BaseDO):
+
+class PodDO(BaseModel):
     name: str
     node_name: str
     pod_status: str
-    age: str
+    age: Union[str, datetime.timedelta]
     pod_ip: str
     namespace: str
     restarts: str
     readiness_info: Optional[str]
     _life_time: int=5
 
-@dataclass
-class PodOSSOperationInfoDO(BaseDO):
+
+class IngressDO(BaseModel):
     name: str
-    cluster_name: str
-    namespace_name: str
+    host_info: str
+    address_info: str
+    port: int
+    age: Union[str, datetime.timedelta]
+    namespace: str
+    _life_time: int=5
+
+
+class ServiceDO(BaseModel):
+    name: str
+    service_type: str
+    cluster_ip: str
+    external_ip: Optional[str]
+    port_info: str
+    age: Union[str, datetime.timedelta]
+    _life_time: int=5
+
+
+class PodContainerDO(BaseModel):
     pod_name: str
-    container_name: str
-    target_dir: str
-    local_path: str
+    init_container_info: str
+    container_info: str
+    _life_time: int=5
+
+class ReleaseNodeInfoDO(BaseModel):
+    node_name: str
+    region_id: str
+    instance_id: str
+
+# class ReleaseInstanceInfoDO(BaseModel):
+#     region_id: str
+#     instance_id: str
+
+
 
 class NodeMetaDO(BaseModel):
     name: str
     status: str
     run_time: Union[str, datetime.timedelta]
     k3s_version: str
+    private_ip: str
     label: Union[str, Dict]
-    private_ip: str
-    _life_time: int=5
 
-@dataclass
-class IngressDO(BaseDO):
-    name: str
-    host_info: str
-    address_info: str
-    port: int
-    age: str
-    namespace: str
-    _life_time: int=5
-
-@dataclass
-class InstanceInfoDO(BaseDO):
-    id: str
-    status: str
-    security_group_id: List[str]
-    instance_type: str
-    name: str
-    hostname: str
-    price: float
-    image_id: str
-    region_id: str
-    zone_id: str
-    internet_pay_type: str
-    pay_type: str
-    create_time: str
-    os_name: str
-    public_ip: List[str]
-    private_ip: str
-    bandwidth_in: str
-    bandwidth_out: str
-    expired_time: str
-    auto_release_time: str
-    key_name: str
-    _life_time: int=5
-
-@dataclass
-class InstanceUserSettingDO(BaseDO):
-    name: str
-    password: str
-    image_id: str
-    region_id: str
-    exclude_instance_types: List[str]
-    user_data: Optional[str]=None
-    internet_pay_type: str='PayByTraffic'
-    amount: int=1
-    bandwidth_in: int=200
-    bandwidth_out: int=1
-    disk_size: int=20
-    key_name: str='ansible'
-    inner_connection: bool=True
-
-@dataclass
-class CommandSettingDO(BaseDO):
-    command: str='echo 123'
-    forks: int=100
-    timeout: int=30
-    password: str=None
-    username: str='root'
-    port: int=22
-    inner_connection: bool=True
-
-@dataclass
-class OSSOperationInfoDO(BaseDO):
-    name: str
-    endpoint: str
-    bucket_name: str
-    local_path: str
-    target_path: str
-    with_tar: bool=False
-
-@dataclass
-class InstanceTypeWithStatusDO(BaseDO):
-    region_id: str
-    zone_id: str
-    instance_type_id: str
-    cpu_number: int
-    memory_size: float
-    gpu_type: str
-    gpu_number: int
-    status: str
-    status_category: str
-    _life_time: int=5
-
-@dataclass
-class InstanceTypeUserSettingDO(BaseDO):
-    region_id: str
-    zone_id: str
-    instance_type_id: str
-
-@dataclass
-class DNSRecordDO(BaseDO):
-    domain_name: str
-    subdomain: str
-    value: str
-    id: Optional[str]=None
-    weight: Optional[int]=None
-    dns_type: str='A'
-    ttl: int=600
-    priority: Optional[int]=None
-    line: Optional[str]=None
-
-@dataclass
-class ServiceDO(BaseDO):
-    name: str
-    service_type: str
-    cluster_ip: str
-    external_ip: Optional[str]
-    port_info: str
-    age: str
-    _life_time: int=5
-
-@dataclass
-class PodContainerDO(BaseDO):
-    pod_name: str
-    init_container_info: str
-    container_info: str
-    _life_time: int=5
 
 class KeyToPathDO(BaseModel):
     key: str
     path: str
     mode: Optional[int]=None
 
+
 class EnvVarSourceDO(BaseModel):
     env_var_source_type: str
     key: str
     name: str
     optional: Optional[bool]=None
 
+
 class EnvVarDO(BaseModel):
     name: str
     value_from: Optional[EnvVarSourceDO] = None
     value: Optional[str]=None
 
+
 class VolumeSourceDO(BaseModel):
     name: str  
     volume_type: str
@@ -311,10 +216,12 @@ class VolumeSourceDO(BaseModel):
     items: Optional[List[KeyToPathDO]] = None
     optional: Optional[bool] = None
 
+
 class PersistentVolumeClaimeVolumeSourceDO(BaseModel):
     claim_name: str
     read_only: Optional[bool] = None
 
+
 class VolumeSettingDO(BaseModel):
     volume_name: str
     empty_dir: Optional[bool] = None
@@ -322,12 +229,14 @@ class VolumeSettingDO(BaseModel):
     secret: Optional[VolumeSourceDO] = None
     persistent_volume_claim: Optional[PersistentVolumeClaimeVolumeSourceDO] = None
 
+
 class VolumeMountDO(BaseModel):
     name: str
     mount_path: str
     read_only: Optional[bool]=None
     sub_path: Optional[str]=None
 
+
 class ContainerPortDO(BaseModel):
     port: int
     name: Optional[str] = None
@@ -335,6 +244,7 @@ class ContainerPortDO(BaseModel):
     host_ip: Optional[str] = None
     host_port: Optional[int] = None
 
+
 class HTTPGetActionDO(BaseModel):
     port: int
     host: Optional[str] = None
@@ -342,14 +252,17 @@ class HTTPGetActionDO(BaseModel):
     http_headers: Optional[List[Dict]] = None
     scheme: Optional[str] = None
 
+
 class TCPSocketActionDO(BaseModel):
     port: int
     host: Optional[str] = None
 
+
 class GRPCActionDO(BaseModel):
     port: int
     service: Optional[str] = None
 
+
 class ProbeDO(BaseModel):
     initial_delay_seconds: int = 10
     period_seconds: int = 10
@@ -361,20 +274,24 @@ class ProbeDO(BaseModel):
     http_get: Optional[HTTPGetActionDO] = None
     tcp_socket: Optional[TCPSocketActionDO] = None
 
+
 class LabelSelectorRequirementDO(BaseModel):
     key: str
     operator: str
     values: Optional[List[str]] = None
 
+
 class LabelSelectorDO(BaseModel):
     match_expressions: Optional[List[LabelSelectorRequirementDO]] = None
     match_labels: Optional[Dict] = None
 
+
 class SecurityContextDO(BaseModel):
     privileged: Optional[bool]=None
     run_as_user: Optional[int]=None
     run_as_non_root: Optional[bool]=None
 
+
 class ContainerSettingDO(BaseModel):
     container_name: str
     container_image: str
@@ -391,6 +308,7 @@ class ContainerSettingDO(BaseModel):
     liveness_probe: Optional[ProbeDO] = None
     ports: Optional[List[ContainerPortDO]] = None
 
+
 class JobSettingDO(BaseModel):
     job_name: str
     namespace_name: str
@@ -408,8 +326,8 @@ class JobSettingDO(BaseModel):
     dns_policy: Optional[str] = None
     service_account_name: Optional[str] = None
 
-@dataclass
-class JobDO(BaseDO):
+
+class JobDO(BaseModel):
     name: str
     age: Union[str, datetime.timedelta]
     namespace: str
@@ -417,13 +335,14 @@ class JobDO(BaseDO):
     parallelism: int
     _life_time: int=5
 
-@dataclass
-class PodLogSettingDO(BaseDO):
+
+class PodLogSettingDO(BaseModel):
     namespace_name: str
     pod_name: str
     container_name: Optional[str]=None
     tail_lines: int=500
 
+
 class StorageClassDO(BaseModel):
     name: str
     provisioner: str
@@ -431,24 +350,29 @@ class StorageClassDO(BaseModel):
     volume_binding_mode: str
     namespace_name: str
 
+
 class NFSVolumeSourceDO(BaseModel):
     path: str
     server: str
     read_only: Optional[bool]=None
 
+
 class LocalVolumeSourceDO(BaseModel):
     path: str
     fs_type: Optional[str]=None
 
+
 class NodeSelectorRequirementDO(BaseModel):
     key: str
     operator: str
     values: List[str]
 
+
 class NodeAffinityDO(BaseModel):
     match_expressions: Optional[List[NodeSelectorRequirementDO]]=None
     match_fields: Optional[List[NodeSelectorRequirementDO]]=None
 
+
 class PersistentVolumeDO(BaseModel):
     name: str
     namespace: str
@@ -461,6 +385,7 @@ class PersistentVolumeDO(BaseModel):
     local: Optional[LocalVolumeSourceDO]=None
     node_affinity: Optional[List[NodeAffinityDO]]=None
 
+
 class PersistentVolumeClaimDO(BaseModel):
     name: str
     namespace: str
@@ -470,7 +395,19 @@ class PersistentVolumeClaimDO(BaseModel):
     limits: Optional[Dict]=None
     requests: Optional[Dict]=None
 
-class ReleaseNodeInfoDO(BaseModel):
-    node_name: str
-    region_id: str
-    instance_id: str
\ No newline at end of file
+class DatapipeServerInfoDO(BaseModel):
+    id: str
+    secret: str
+    endpoint: str
+
+class DatapipeHostDO(CommandHostDO):
+    pass
+
+class DatapipeDataInfoDO(BaseModel):
+    bucket: str
+    remote_path: str
+    local_path: str
+    timeout: int = 3
+
+class DatapipeResponseDO(CommandResponseDO):
+    pass
