@@ -1,4 +1,3 @@
-import os, json, time
 from typing import List, Optional, Tuple, Union
 from ddd_objects.infrastructure.repository_impl import RepositoryImpl
 from ddd_objects.lib import Logger
@@ -29,7 +28,6 @@ from ..domain.entity import (
     PodLogSetting,
     PodOSSOperationInfo,
     ConfigMap,
-    CommandResult,
     Pod,
     ConfigMapUserSetting,
     Secret,
@@ -40,8 +38,6 @@ from ..domain.entity import (
     Service
 )
 from ..domain.value_obj import (
-    Integer,
-    Number,
     Key,
     Bool,
     Name,
@@ -485,6 +481,16 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             cluster_name=cluster_name,
             namespace_name=namespace_name
         )
+
+    def delete_job(self, cluster_name: Name, namespace_name: Name, job_name: Name)->bool:
+        cluster_name = cluster_name.get_value()
+        namespace_name = namespace_name.get_value()
+        job_name = job_name.get_value()
+        result = self.ao.delete_job(cluster_name, namespace_name, job_name)
+        if result.succeed and result.get_value() is not None:
+            return result.get_value()
+        else:
+            return False
     
     def get_pod_log(
         self, 
